@@ -4,7 +4,7 @@ use 5.008005;
 use strict;
 use warnings;
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 1;
 __END__
@@ -21,7 +21,7 @@ JSV - JSON Schema implementation of Perl
 
 =head1 DESCRIPTION
 
-JSV is ...
+See e.g. L<JSV::Validator>
 
 =head1 LICENSE
 
